<img src="namdtools.svg" alt="namdtools" height="200px">

a Python interface to NAMD  
http://www.ks.uiuc.edu/Research/namd/

<!--*master:*-->
<span style="white-space: nowrap;">
    <a href="https://pypi.org/project/namdtools/"><img src="https://img.shields.io/pypi/v/namdtools" /></a>
    <a href="https://travis-ci.com/github/LockhartLab/namdtools"><img src="https://img.shields.io/travis/com/lockhartlab/namdtools/master" /></a>
    <a href="https://codecov.io/gh/LockhartLab/namdtools"><img src="https://img.shields.io/codecov/c/github/lockhartlab/namdtools/master" /></a>
</span>

<hr>

note that this package is **still in development**  
at this stage, I'm only building thing as they come to mind  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

yet, install simply by calling ```pip install namdtools```

<hr>

Related Packages
----------------
https://github.com/sunhwan/NAMD-replica  
https://github.com/bio-phys/MDBenchmark  
https://github.com/radakb/pynamd/
